// @ts-check
// Note: type annotations allow type checking and IDEs autocompletion

const lightCodeTheme = require("prism-react-renderer/themes/github");
const darkCodeTheme = require("prism-react-renderer/themes/dracula");

/** @type {import('@docusaurus/types').Config} */
const config = {
  title: "Doc PLS5618",
  tagline: "Documentation PLS5618",
  favicon: "img/favicon.ico",

  //themes: ["@docusaurus/theme-search-algolia"],

  // Set the production url of your site here
  url: "https://docs.pls5618.com",
  // Set the /<baseUrl>/ pathname under which your site is served
  // For GitHub pages deployment, it is often '/<projectName>/'
  baseUrl: "/",

  onBrokenLinks: "throw",
  onBrokenMarkdownLinks: "warn",

  // Even if you don't use internalization, you can use this field to set useful
  // metadata like html lang. For example, if your site is Chinese, you may want
  // to replace "en" with "zh-Hans".
  i18n: {
    defaultLocale: "fr",
    locales: ["fr"],
  },

  presets: [
    [
      "classic",
      /** @type {import('@docusaurus/preset-classic').Options} */
      ({
        docs: false,
        theme: {
          customCss: require.resolve("./src/css/custom.css"),
        },
      }),
    ],
  ],

  plugins: [
    [
      "@docusaurus/plugin-content-docs",
      {
        id: "java",
        path: "java",
        routeBasePath: "java",
        sidebarPath: require.resolve("./sidebars.js"),
      },
    ],
    [
      "@docusaurus/plugin-content-docs",
      {
        id: "robot",
        path: "robot",
        routeBasePath: "robot",
        sidebarPath: require.resolve("./sidebars2.js"),
      },
    ],
  ],

  themeConfig:
    /** @type {import('@docusaurus/preset-classic').ThemeConfig} */
    ({
      // Replace with your project's social card
      image: "img/logo.png",
      navbar: {
        title: "PLS 5618",
        logo: {
          alt: "PLS 5618",
          src: "img/logo.png",
        },
        items: [
          {
            type: "doc",
            docId: "index",
            position: "left",
            label: "Java",
            docsPluginId: "java",
          },
          {
            type: "doc",
            docId: "index",
            position: "left",
            label: "Robot",
            docsPluginId: "robot",
          },
        ],
      },
      footer: {
        style: "dark",
        links: [
          {
            title: "Documentation",
            items: [
              {
                label: "Java",
                to: "/java",
              },
              {
                label: "Robot",
                to: "/robot",
              },
            ],
          },
          {
            title: "Communauté",
            items: [
              {
                label: "Facebook",
                href: "https://www.facebook.com/PLS5618",
              },
              {
                label: "Twitter",
                href: "https://twitter.com/pls5618",
              },
              {
                label: "Instagram",
                href: "https://www.instagram.com/team5618",
              },
              {
                label: "Site Internet",
                href: "https://pls5618.com/",
              },
            ],
          },
        ],
        copyright: `Copyright © ${new Date().getFullYear()} PLS 5618. Fait avec Docusaurus.`,
      },
      prism: {
        additionalLanguages: ["java"],
        theme: lightCodeTheme,
        darkTheme: darkCodeTheme,
      },
      //  algolia: {
      //    appId: "",
      //    apiKey: "",
      //    indexName: "",
      //    contextualSearch: true,
      //  },
    }),
};

module.exports = config;
